//	@阿杰爱学单片机 2024/08/027
// 	按键控制LED示例：按下P3.5,LED1状态取反，按下P3.4,LED2状态取反，
//  按下P3.3,LED左移一位，按下P3.2LED流水灯一次
//	实验开发板：STC32G12K128屠龙刀三.1 主频@24MHz

#include "COMM/stc.h"		//调用头文件
#include "COMM/usb.h"

#define MAIN_Fosc 24000000UL		//定义主频24MHz

#define Key1 P35
#define Key2 P34
#define Key3 P33
#define Key4 P32
#define LED1 P20
#define LED2 P27

void SYS_Init(void);						// STC32初始化设置
void MyUSB_Init(void);					//USB不断电下载配置初始化设置
void GPIO_Init(void);						//IO口初始化设置
void delay_ms(u16 ms);


//------USB调试及复位所需定义-----
char *USER_DEVICEDESC = NULL;
char *USER_PRODUCTDESC = NULL;
char *USER_STCISPCMD = "@STCISP#"; 	//设置自动复位到ISP区的用户接口命令

u8 i;
LED_Buff[]={0xfe,0xfd,0xfb,0xf7,0xef,0xdf,0xbf,0x7f};



void main(void)      //主函数(程序从这里执行)
{
	SYS_Init();					// STC32初始化
	MyUSB_Init();				//USB初始化
	GPIO_Init();				//IO口初始化
	while(1)
	{
		if( DeviceState != DEVSTATE_CONFIGURED ) 	//
			continue;
		if( bUsbOutReady )								
		{
			usb_OUT_done();
		}
//----------------按键控制LED--------------------//
		if(Key1 == 0)				//如果按键1按下
		{
			delay_ms(10);			//延时消抖
			while(Key1 ==  0);//如果按键1按下死循环，等待松手
			delay_ms(10);			//延时消抖
			LED1=!LED1;				//LED1状态取反
			printf("按键1按下LED取反%\r\n");
		}
		if(Key2 == 0)				//如果按键2按下
		{
			delay_ms(10);			//延时消抖
			while(Key2 ==  0);//如果按键2按下死循环，等待松手
			delay_ms(10);			//延时消抖
			LED2=~LED2;				//LED2状态取反
			printf("按键2按下LED取反%\r\n");
		}
		if(Key3 == 0)				//如果按键3按下
		{
			delay_ms(10);			//延时消抖
			while(Key3 ==  0);//如果按键3按下死循环，等待松手
			delay_ms(10);			//延时消抖
			P2=LED_Buff[i++]; //按键按下依次取数组中的元素，实现LED左移1位的效果
			i%=8;							//如果i=8,i就=0;相同的数取余结果为零
			printf("按键3按下LED左移一位%\r\n");
		}
		if(Key4 == 0)				//如果按键4按下
		{
			delay_ms(10);			//延时消抖
			while(Key4 ==  0);//如果按键4按下死循环，等待松手
			delay_ms(10);			//延时消抖
			printf("按键4按下LED流水灯一次%\r\n");
			for(i=0;i<8;i++)	//for循环执行流水灯
			{
				P2=LED_Buff[i];
				delay_ms(300);
			}
		}
//------------------------------------------//
	}
}

void SYS_Init()
{
	EAXFR = 1; 									// 使能访问 XFR
	CKCON = 0x00; 							// 设置外部数据总线速度为最快
	WTST = 0x00;								// 设置程序代码等待参数，等待时间为0个时钟，CPU执行程序速度最快
}

void GPIO_Init(void)
{
	P2M0=0x00;				//P2设置为准双向口
	P2M1=0x00;
}

void MyUSB_Init(void)
{
	//------USB调试及复位所需代码-----
  P3M0 &= ~0x03;
  P3M1 |= 0x03;
	
  IRC48MCR = 0x80;					 //使能内部48M高速IRC
  while (!(IRC48MCR & 0x01));//等待时钟稳定
	
	//CDC下载需要用下面这两行,若使用HID下载请屏蔽//
	 USBCLK = 0x00;
	 USBCON = 0x90;
	
	usb_init();								 //usb初始化
	//--------------------------------
	EA = 1;							// 使能EA总中断
}

void delay_ms(u16 ms)
{
	u16 i;
	do
	{
		i=MAIN_Fosc/6000;
		while(--i);
	}
	while(--ms);
}

